pub struct ChainContext {
pub network: String,
pub extra: HashMap<String, String>,
}Expand description
Stored in the parent value of chain wrapper types so cube resolvers can
retrieve the active chain without a network argument on themselves.
Service-layer extra_args values are available in the extra map.
Fields
network: Stringextra: HashMap<String, String>Auto Trait Implementations
impl Freeze for ChainContext
impl RefUnwindSafe for ChainContext
impl Send for ChainContext
impl Sync for ChainContext
impl Unpin for ChainContext
impl UnsafeUnpin for ChainContext
impl UnwindSafe for ChainContext